VideoControllerMediaInfo class
This type is used by VideoController.mediaInfo. duration == 0 means the media is realtime stream. audioTracks and subtitleTracks are maps with track id as key.
Constructors
-
VideoControllerMediaInfo(int duration, Map<
String, VideoControllerAudioInfo> audioTracks, Map<String, VideoControllerSubtitleInfo> subtitleTracks, String source) -
const
Properties
-
audioTracks
→ Map<
String, VideoControllerAudioInfo> -
final
- duration → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
-
subtitleTracks
→ Map<
String, VideoControllerSubtitleInfo> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited