VideoControllerProperty<T> class
This class is used by VideoController to notify listeners when
property changes. The value setter is protected, you may see warnings
when trying to assign value to it.
- Inheritance
-
- Object
- AsyncValueNotifier<
T> - VideoControllerProperty
- Implemented types
Constructors
- VideoControllerProperty(T value, {bool cancelable = false, bool distinct = false})
Properties
- cancelable ↔ bool
-
Whether the notifier should ignore unchanged notifications.
getter/setter pairinherited
- dispatching → bool
-
Whether the notifier is currently dispatching notifications.
no setterinherited
- disposed → bool
-
Whether the notifier has been disposed.
no setterinherited
- distinct ↔ bool
-
Whether the notifier should ignore duplicate listeners while triggering.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEqual ↔ bool Function(T, T)?
-
The comparison function used to determine if two values are equal.
getter/setter pairinherited
-
listeners
→ List<
VoidCallback> -
Returns a list of active listener callbacks.
no setterinherited
- pending → bool
-
Whether the notifier is currently pending notification.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ T
-
The current value of the object. When the value changes, the callbacks
registered with addListener will be invoked.
getter/setter pairinherited-getteroverride-setter
- weakListener → bool
-
Whether the notifier should use weak references for listeners. If true, listeners that are no longer strongly referenced elsewhere will be garbage collected and automatically removed.
finalinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object notifies its listeners. This operation takes effect while
dispatchingis false.inherited -
dispose(
) → void -
Disposes the notifier and (eagerly) clears listeners.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeListener(
VoidCallback listener) → void -
Unregisters a closure so it will no longer be called when the object notifies its listeners. This operation takes effect while
dispatchingis false.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited